from django.apps import AppConfig


class FinePermissionsConfig(AppConfig):
    default_auto_field = 'django.db.models.AutoField'
    name = 'rest_framework_fine_permissions'
    verbose_name = 'Rest Framework Fine Permissions'
